package cn.iocoder.yudao.module.system.api.remote;

import cn.hutool.core.util.ObjectUtil;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import cn.iocoder.yudao.module.system.api.remote.dto.*;
import cn.iocoder.yudao.module.system.controller.admin.robot.camera.RobotCameraAddVO;
import cn.iocoder.yudao.module.system.service.robot.RobotTaskDetailService;
import cn.iocoder.yudao.module.system.service.robot.camera.RobotCameraService;
import cn.iocoder.yudao.module.system.util.aes.AESEncryptionUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

@Slf4j
@RestController // 提供 RESTful API 接口，给 Feign 调用
@Validated
public class RemoteExceptionTaskApiImpl implements RemoteExceptionTaskApi{


    @Resource
    private RobotTaskDetailService taskDetailService;

    @Resource
    private RobotCameraService cameraService;

    @Value("${zn.camera_secret_key}")
    private String cameraSecretKey;

    /**
     * 远遥查询异常的车辆
     * @param remoteTaskQuery
     * @return
     */
    @Override
    public PageResult<RemoteExceptionTaskDetailDTO> getExceptionTaskDetail(RemoteTaskQueryDTO remoteTaskQuery) {
        return taskDetailService.getExceptionTaskDetail(remoteTaskQuery);
    }

    @Override
    public List<RemoteRobotCameraDTO> getCarmeraByRobotNo(String robotNo) {
        List<RobotCameraAddVO> cameraByRobotNo = cameraService.getCameraByRobotNo(robotNo);
        if (ObjectUtil.isEmpty(cameraByRobotNo)) {
            return new ArrayList<>();
        }
        List<RemoteRobotCameraDTO> list = BeanUtils.toBean(cameraByRobotNo, RemoteRobotCameraDTO.class);

        for (RemoteRobotCameraDTO robotCameraDO : list) {
            try {
                robotCameraDO.setCameraAccount(AESEncryptionUtil.decrypt(robotCameraDO.getCameraAccount(),cameraSecretKey));
                robotCameraDO.setCameraPassword(AESEncryptionUtil.decrypt(robotCameraDO.getCameraPassword(),cameraSecretKey));
            } catch (Exception e) {
                throw new RuntimeException(e);
            }
        }

        return list;
    }

}
