package cn.iocoder.yudao.module.system.service.remote;

import cn.hutool.core.util.ObjectUtil;
import cn.iocoder.yudao.module.system.api.remote.dto.RemoteRobotMaxSpeedDTO;
import cn.iocoder.yudao.module.system.controller.admin.remote.vo.RobotMaxSpeedPageReqVO;
import cn.iocoder.yudao.module.system.controller.admin.remote.vo.RobotMaxSpeedRespVO;
import cn.iocoder.yudao.module.system.controller.admin.remote.vo.RobotMaxSpeedSaveReqVO;
import cn.iocoder.yudao.module.system.dal.dataobject.houselane.WareHouseLaneDO;
import cn.iocoder.yudao.module.system.dal.dataobject.remote.RobotMaxSpeedDO;
import cn.iocoder.yudao.module.system.dal.dataobject.robot.RobotInformationDO;
import cn.iocoder.yudao.module.system.dal.mysql.remote.RobotMaxSpeedMapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

import org.springframework.validation.annotation.Validated;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;


import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.system.enums.ErrorCodeConstants.ROBOT_MAX_SPEED_NOT_EXISTS;

/**
 * 远遥车辆最大速度 Service 实现类
 *
 * @author 陈宾顺
 */
@Service
@Validated
public class RobotMaxSpeedServiceImpl extends ServiceImpl<RobotMaxSpeedMapper, RobotMaxSpeedDO> implements RobotMaxSpeedService {

    @Resource
    private RobotMaxSpeedMapper robotMaxSpeedMapper;

    @Override
    public Long createRobotMaxSpeed(RobotMaxSpeedSaveReqVO createReqVO) {
        // 插入
        RobotMaxSpeedDO robotMaxSpeed = BeanUtils.toBean(createReqVO, RobotMaxSpeedDO.class);
        robotMaxSpeedMapper.insert(robotMaxSpeed);
        // 返回
        return robotMaxSpeed.getId();
    }

    @Override
    public void updateRobotMaxSpeed(RobotMaxSpeedSaveReqVO updateReqVO) {
        // 校验存在
        validateRobotMaxSpeedExists(updateReqVO.getId());
        // 更新
        RobotMaxSpeedDO updateObj = BeanUtils.toBean(updateReqVO, RobotMaxSpeedDO.class);
        robotMaxSpeedMapper.updateById(updateObj);
    }

    @Override
    public void deleteRobotMaxSpeed(Long id) {
        // 校验存在
        validateRobotMaxSpeedExists(id);
        // 删除
        robotMaxSpeedMapper.deleteById(id);
    }

    private void validateRobotMaxSpeedExists(Long id) {
        if (robotMaxSpeedMapper.selectById(id) == null) {
            throw exception(ROBOT_MAX_SPEED_NOT_EXISTS);
        }
    }

    @Override
    public RobotMaxSpeedDO getRobotMaxSpeed(Long id) {
        return robotMaxSpeedMapper.selectById(id);
    }

    @Override
    public PageResult<RobotMaxSpeedDO> getRobotMaxSpeedPage(RobotMaxSpeedPageReqVO pageReqVO) {
        return robotMaxSpeedMapper.selectPage(pageReqVO);
    }

    /**
     * 更新车辆编号
     *
     * @param oldRobotNo
     * @param newRobotNo
     */
    @Override
    public void updateRobotNo(String oldRobotNo, String newRobotNo) {
        robotMaxSpeedMapper.updateRobotNo(oldRobotNo, newRobotNo);
    }

    @Override
    public void deleteByRobotNo(String robotNo) {
        robotMaxSpeedMapper.deleteByRobotNo(robotNo);
    }

    @Override
    public List<RemoteRobotMaxSpeedDTO> getAllRobotMaxSpeedList() {
        List<RobotMaxSpeedDO> list = robotMaxSpeedMapper.selectList(new LambdaQueryWrapper<RobotMaxSpeedDO>());
        if (ObjectUtil.isEmpty(list)) {
            return new ArrayList<>();
        }

        List<RemoteRobotMaxSpeedDTO> bean = BeanUtils.toBean(list, RemoteRobotMaxSpeedDTO.class);
        return bean;
    }

    @Override
    public void updateRobotMaxSpeedList(List<RemoteRobotMaxSpeedDTO> list) {
        List<RobotMaxSpeedDO> bean = BeanUtils.toBean(list, RobotMaxSpeedDO.class);
        robotMaxSpeedMapper.updateById(bean);
    }

    @Override
    public String getRobotMaxSpeedByRobotNo(String robotNo) {
        RobotMaxSpeedDO robotMaxSpeedDO = robotMaxSpeedMapper.selectOne(new LambdaQueryWrapper<RobotMaxSpeedDO>()
                .eq(RobotMaxSpeedDO::getRobotNo, robotNo)
                .last("limit 1"));
        return ObjectUtil.isEmpty(robotMaxSpeedDO) ? null : robotMaxSpeedDO.getMaxSpeed();
    }

}
